#!/bin/bash
#
# Copyright 2022 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

set -e
set -x


if [ -z "$(which git)" ]; then
	apt-get -y update
	apt-get -y install git
fi

token_file="/root/git-access-token.secret"
if [ -e "$token_file" ] && [ -n "$JOB_NAME" ]; then
	curl -k https://nissedal.knut.univention.de/ucs-root-ca.crt > /usr/local/share/ca-certificates/univention.crt
	update-ca-certificates
	git config --global --add user.name "Jenkins ID Broker Performance Tests"
	git config --global --add user.email "brokertests@jenkins"
	git clone "https://token:$(< $token_file)@git.knut.univention.de/univention/id-broker/performance-test-results.git" /tmp/performance-test-results
	test_name="$(basename "$JOB_NAME")"
	version="$(ucr get version/version)"
	result_dir="results-$(date +%Y-%m-%d-%H-%M)"
	cd /tmp/performance-test-results
	mkdir -p "$version/$test_name/$result_dir"
	cp -rf /var/lib/id-broker-performance-tests/system-information "$version/$test_name/$result_dir/"
	cp -rf /var/lib/id-broker-performance-tests/results/*.csv "$version/$test_name/$result_dir/"
	# shellcheck disable=SC2035
	git add *
	git commit -a -m "Performance test results update for job \"$JOB_NAME\""
	git push
fi

exit 0
